@@ -27,21 +27,20 @@
 #include "kernel.h"
 
 #include "akregator_debug.h"
-#include <kiconloader.h>
-#include <kicontheme.h>
 #include <KLocalizedString>
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <QUrl>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QStyle>
 
 using namespace Akregator;
 AddFeedWidget::AddFeedWidget(QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this);
-    pixmapLabel1->setPixmap(QIcon::fromTheme(QStringLiteral("applications-internet")).pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)));
+    pixmapLabel1->setPixmap(QIcon::fromTheme(QStringLiteral("applications-internet")).pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)));
     statusLabel->setText(QString());
 }
 
@@ -66,7 +65,7 @@ AddFeedDialog::AddFeedDialog(QWidget *parent, const QString &name)
     : QDialog(parent)
 {
     setObjectName(name);
-    setWindowTitle(i18n("Add Feed"));
+    setWindowTitle(i18nc("@title:window", "Add Feed"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     widget = new AddFeedWidget(this);
