@@ -29,9 +29,8 @@
 #include "types.h"
 #include <QUrl>
 #include <KConfig>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include "akregator_debug.h"
-#include <krandom.h>
 
 #include <QRegExp>
 
